Package 'jmbr'

Title: Analyses Using JAGS
Description: Facilitates analyses using 'Just Another Gibbs Sampler'.
Authors: Joe Thorley [aut, cre] (ORCID: <https://orcid.org/0000-0002-7683-4592>), Kirill Müller [ctb] (ORCID: <https://orcid.org/0000-0002-1416-3412>), Poisson Consulting [cph, fnd]
Maintainer: Joe Thorley <[email protected]>
License: MIT + file LICENSE
Version: 0.0.0.9146
Built: 2026-06-03 22:03:20 UTC
Source: https://github.com/poissonconsulting/jmbr

Help Index


Is a JAGS Analysis

Description

Tests whether x is an object of class 'jmb_analysis'

Usage

is.jmb_analysis(x)

Arguments

x

The object to test.

Value

A flag indicating whether the test was positive.


Is JAGS Code

Description

Tests whether x is an object of class 'jmb_code'

Usage

is.jmb_code(x)

Arguments

x

The object to test.

Value

A flag indicating whether the test was positive.


Is a JAGS Model

Description

Tests whether x is an object of class 'jmb_model'

Usage

is.jmb_model(x)

Arguments

x

The object to test.

Value

A flag indicating whether the test was positive.